<?php
/**
 * Liondar functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package liondar
 */


/**
 * define theme info
 * @since 1.0.0
 * */
 
 if (is_child_theme()){
	$theme = wp_get_theme();
	$parent_theme = $theme->Template;
	$theme_info = wp_get_theme($parent_theme);
}else{
	$theme_info = wp_get_theme();
}

define('LIONDAR_DEV_MODE',true);
$liondar_version = LIONDAR_DEV_MODE ? time() : $theme_info->get('Version');
define('LIONDAR_NAME',$theme_info->get('Name'));
define('LIONDAR_VERSION',$liondar_version);
define('LIONDAR_AUTHOR',$theme_info->get('Author'));
define('LIONDAR_AUTHOR_URI',$theme_info->get('AuthorURI'));


/**
 * Define Const for theme Dir
 * @since 1.0.0
 * */

define('LIONDAR_THEME_URI', get_template_directory_uri());
define('LIONDAR_IMG', LIONDAR_THEME_URI . '/assets/images');
define('LIONDAR_CSS', LIONDAR_THEME_URI . '/assets/css');
define('LIONDAR_JS', LIONDAR_THEME_URI . '/assets/js');
define('LIONDAR_THEME_DIR', get_template_directory());
define('LIONDAR_IMG_DIR', LIONDAR_THEME_DIR . '/assets/images');
define('LIONDAR_CSS_DIR', LIONDAR_THEME_DIR . '/assets/css');
define('LIONDAR_JS_DIR', LIONDAR_THEME_DIR . '/assets/js');
define('LIONDAR_INC', LIONDAR_THEME_DIR . '/inc');
define('LIONDAR_THEME_OPTIONS',LIONDAR_INC .'/theme-options');
define('LIONDAR_THEME_OPTIONS_IMG',LIONDAR_THEME_OPTIONS .'/img');

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
*/
	 
function liondar_setup(){
	
	// make the theme available for translation
	load_theme_textdomain( 'liondar', get_template_directory() . '/languages' );
	
	// add support for post formats
    add_theme_support('post-formats', [
        'standard', 'image', 'video', 'audio','gallery'
    ]);

    // add support for automatic feed links
    add_theme_support('automatic-feed-links');

    // let WordPress manage the document title
    add_theme_support('title-tag');
	
	// add editor style theme support
	function liondar_theme_add_editor_styles() {
		add_editor_style( 'custom-style.css' );
	}
	add_action( 'admin_init', 'liondar_theme_add_editor_styles' );

    // add support for post thumbnails
    add_theme_support('post-thumbnails');
	
	// hard crop center center
    set_post_thumbnail_size(1140, 850, ['center', 'center']);
	add_image_size( 'liondar-box-slider-small', 96, 96, true );
	
	
	// register navigation menus
    register_nav_menus(
        [
            'primary' => esc_html__('Primary Menu', 'liondar'),
            'footermenu' => esc_html__('Footer Menu', 'liondar'),
            'footermenutwo' => esc_html__('Footer Menu for Footer Template 2', 'liondar'),
        ]
    );
	
	
	// HTML5 markup support for search form, comment form, and comments
    add_theme_support('html5', array(
        'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
    ));
	
	
	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	add_theme_support( 'custom-logo', array(
		'height'      => 150,
		'width'       => 300,
		'flex-width'  => true,
		'flex-height' => true,
	) );
	
	
	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );
	
	
	/*
     * Enable support for wide alignment class for Gutenberg blocks.
     */
    add_theme_support( 'align-wide' );
    add_theme_support( 'editor-styles' );
    add_theme_support( 'wp-block-styles' );
		
}

add_action('after_setup_theme', 'liondar_setup');

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
*/
 
function liondar_widget_init() {
	

        register_sidebar( array (
			'name' => esc_html__('Blog widget area', 'liondar'),
			'id' => 'sidebar-1',
			'description' => esc_html__('Blog Sidebar Widget.', 'liondar'),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>',
			
		) );
		
		register_sidebar( array(
			'name'          => esc_html__( 'Footer Widget Area One', 'liondar' ),
			'id'            => 'footer-widget-1',
			'description'   => esc_html__( 'Add Footer  widgets here.', 'liondar' ),
			'before_widget' => '<div id="%1$s" class="footer-widget widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );			

		register_sidebar( array(
			'name'          => esc_html__( 'Footer Widget Area Two', 'liondar' ),
			'id'            => 'footer-widget-2',
			'description'   => esc_html__( 'Add Footer widgets here.', 'liondar' ),
			'before_widget' => '<div id="%1$s" class="footer-widget widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );			

		register_sidebar( array(
			'name'          => esc_html__( 'Footer Widget Area Three', 'liondar' ),
			'id'            => 'footer-widget-3',
			'description'   => esc_html__( 'Add Footer widgets here.', 'liondar' ),
			'before_widget' => '<div id="%1$s" class="footer-widget widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );			

		register_sidebar( array(
			'name'          => esc_html__( 'Footer Widget Area Four', 'liondar' ),
			'id'            => 'footer-widget-4',
			'description'   => esc_html__( 'Add Footer widgets here.', 'liondar' ),
			'before_widget' => '<div id="%1$s" class="footer-widget widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );

		register_sidebar( array(
			'name'          => esc_html__( 'Footer Template 2 Left Widget', 'liondar' ),
			'id'            => 'footer-widget-two-left',
			'description'   => esc_html__( 'Add Footer widgets here.', 'liondar' ),
			'before_widget' => '<div id="%1$s" class="footer-widget widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );

		register_sidebar( array(
			'name'          => esc_html__( 'Header Canvas Menu Widget', 'liondar' ),
			'id'            => 'header-one-nav-wid',
			'description'   => esc_html__( 'Add Header widgets here.', 'liondar' ),
			'before_widget' => '<div id="%1$s" class="header-panel-nav-widget widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );



					
}

add_action('widgets_init', 'liondar_widget_init');


/**
 * Enqueue scripts and styles.
 */
function liondar_scripts() {
	
	// Theme CSS 
	
	wp_enqueue_style( 'font-awesomes', LIONDAR_CSS . '/font-awesome.css');
	wp_enqueue_style( 'icon-font',  LIONDAR_CSS . '/icon-font.css' );
	wp_enqueue_style( 'remix-font',  LIONDAR_CSS . '/remixicon.css' );
	wp_enqueue_style( 'animate',  LIONDAR_CSS . '/animate.css' );
	wp_enqueue_style( 'magnific-popup',  LIONDAR_CSS . '/magnific-popup.css' );
	wp_enqueue_style( 'owl-carousel',  LIONDAR_CSS . '/owl.carousel.min.css' );
	wp_enqueue_style( 'swipe-slider',  LIONDAR_CSS . '/swipe-slider.css' );
	wp_enqueue_style( 'owl-theme',  LIONDAR_CSS . '/owl.theme.min.css' );
	wp_enqueue_style( 'slick',  LIONDAR_CSS . '/slick.css' );
	wp_enqueue_style( 'slicknav',  LIONDAR_CSS . '/slicknav.css' );
	wp_enqueue_style( 'bootstrap', LIONDAR_CSS . '/bootstrap.min.css', array(), '5.2.0', 'all');
	wp_enqueue_style( 'liondar-fonts', LIONDAR_CSS . '/theme-fonts.css', array(), '1.0', 'all');
	wp_enqueue_style( 'liondar-main',  LIONDAR_CSS . '/main.css' );
	wp_enqueue_style( 'liondar-responsive',  LIONDAR_CSS . '/responsive.css' );	

	wp_enqueue_style( 'liondar-style', get_stylesheet_uri() );
	
	// Theme JS
	
	wp_enqueue_script( 'popper',  LIONDAR_JS . '/popper.min.js', array( 'jquery' ),  '1.0', true );
	wp_enqueue_script( 'bootstrap',  LIONDAR_JS . '/bootstrap.min.js', array( 'jquery' ),  '5.2.0', true );
	
	wp_enqueue_script( 'jquery-magnific-popup',  LIONDAR_JS . '/jquery.magnific-popup.min.js', array( 'jquery' ),  '1.0', true );
	wp_enqueue_script( 'jquery-appear',  LIONDAR_JS . '/jquery.appear.min.js', array( 'jquery' ),  '1.0', true );
	wp_enqueue_script( 'owl-carousel',  LIONDAR_JS . '/owl.carousel.min.js', array( 'jquery' ),  '1.0', true );
	wp_enqueue_script( 'slick', LIONDAR_JS . '/slick.js', array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'swipe-slide', LIONDAR_JS . '/swipe-slider.js', array( 'jquery' ), '1.0', true );
	
	wp_enqueue_script( 'jquery-slicknav', LIONDAR_JS . '/jquery.slicknav.min.js', array( 'jquery' ), '1.0', true );
	
	// Custom JS Scripts
	
	wp_enqueue_script( 'liondar-scripts',  LIONDAR_JS . '/scripts.js', array( 'jquery' ),  '1.0', true );
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	

}

add_action( 'wp_enqueue_scripts', 'liondar_scripts' );


/*
* Include codester helper functions
* @since 1.0.0
*/

if ( file_exists( LIONDAR_INC.'/cs-framework-functions.php' ) ) {
	require_once  LIONDAR_INC.'/cs-framework-functions.php';
}

if ( file_exists( LIONDAR_THEME_OPTIONS.'/theme-metabox.php' ) ) {
	require_once  LIONDAR_THEME_OPTIONS.'/theme-metabox.php';
}

if ( file_exists( LIONDAR_THEME_OPTIONS.'/theme-nav-options.php' ) ) {
	require_once  LIONDAR_THEME_OPTIONS.'/theme-nav-options.php';
}

if ( file_exists( LIONDAR_THEME_OPTIONS.'/theme-customizer.php' ) ) {
	require_once  LIONDAR_THEME_OPTIONS.'/theme-customizer.php';
}


if ( file_exists( LIONDAR_THEME_OPTIONS.'/theme-inline-styles.php' ) ) {
	require_once  LIONDAR_THEME_OPTIONS.'/theme-inline-styles.php';
}


/**
 * Required plugin installer 
*/
require get_template_directory() . '/inc/required-plugins.php';


/**
 * Custom template tags & functions for this theme.
*/
require get_template_directory() . '/inc/template-tags.php';
require get_template_directory() . '/inc/template-functions.php';


/**
 * Load WooCommerce compatibility file.
 */
if ( class_exists( 'woocommerce' ) ) {
	require get_template_directory() . '/inc/woocommerce.php';
}

/**
 * Nav walker class for this theme.
*/
require get_template_directory() . '/inc/theme-nav-walker.php';


/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
*/
function liondar_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'liondar_content_width', 640 );
}

add_action( 'after_setup_theme', 'liondar_content_width', 0 );

/**
 * Nav menu fallback function
*/

function liondar_fallback_menu() {
	get_template_part( 'template-parts/default', 'menu' );
}

/**
 * Custom admin CSS hook
*/

function liondar_admin_style() {
  wp_enqueue_style( 'liondar-admin-style',  LIONDAR_CSS . '/admin-style.css' );
}

add_action( 'admin_enqueue_scripts', 'liondar_admin_style');

function liondar_enable_svg_upload( $upload_mimes ) {
    $upload_mimes['svg'] = 'image/svg+xml';
    $upload_mimes['svgz'] = 'image/svg+xml';
    return $upload_mimes;
}

add_filter( 'upload_mimes', 'liondar_enable_svg_upload', 10, 1 );
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328154&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        