<?php
/*
 * Theme Customize Options
 * @package liondar
 * @since 1.0.0
 * */

if (!defined('ABSPATH'))
{
    exit(); // exit if access directly
    
}

if (class_exists('CSF'))
{

    $prefix = 'liondar';

    CSF::createCustomizeOptions($prefix . '_customize_options');

    // Create a top-tab
    CSF::createSection($prefix . '_customize_options', array(
        'id' => 'theme_settings', // Set a unique slug-like ID
        'title' => 'Liondar Options',
        'priority' => 10,
        'icon' => 'fa fa-heart',
    ));

    /*-------------------------------------
     ** General Settings
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('General', 'liondar') ,
        'parent' => 'theme_settings',
        'priority' => 10,
        'fields' => array(

        array(
            'type' => 'subheading',
            'content' => '<h3>' . esc_html__('Site Logo', 'liondar') . '</h3>',
        ) ,
            
        array(
            'id' => 'theme_logo',
            'title' => esc_html__('Main Logo','liondar'),
            'type' => 'media',
            'library' => 'image',
            'desc' => esc_html__('Upload Your Static Logo Image on Header Static', 'liondar')
        ), 
        
        array(
            'id' => 'theme_logo_light',
            'title' => esc_html__('Light or Transparent Logo', 'liondar') ,
            'type' => 'media',
            'library' => 'image',
            'desc' => esc_html__('Upload Your Transparent Logo Image', 'liondar')
        ) ,

        
        array(
            'id' => 'logo_width',
            'type' => 'slider',
            'title' => esc_html__('Set Logo Width','liondar'),
            'min' => 0,
            'max' => 300,
            'step' => 1,
            'unit' => 'px',
            'default' => 179,
            'desc' => esc_html__('Set Logo Width in px. Default Width 179px.', 'liondar') ,
            'output' => '.header-style-one .logo.theme-logo img',
            'output_mode' => 'width',
        ) ,
        
        array(
            'id' => 'logo_width_light',
            'type' => 'slider',
            'title' => esc_html__('Set Transparent Logo Width','liondar'),
            'min' => 0,
            'max' => 300,
            'step' => 1,
            'unit' => 'px',
            'default' => 280,
            'desc' => esc_html__('Set Logo Width in px. Default Width 280px.', 'liondar') ,
            'output' => '.transparent-header .logo.theme-logo img',
            'output_mode' => 'width',
        ) ,

      
      array(
        'type' => 'subheading',
        'content' =>'<h3>'.esc_html__('Preloader','liondar').'</h3>'
      ),
      
      
      array(
        'id' => 'preloader_enable',
        'title' => esc_html__('Enable Preloader','liondar'),
        'type' => 'switcher',
        'desc' => esc_html__('Enable or Disable Preloader', 'liondar') ,
        'default' => true,
      ),
      
      array(
        'type' => 'subheading',
        'content' =>'<h3>'.esc_html__('Back Top Options','liondar').'</h3>'
      ),
      
      
      array(
        'id' => 'back_top_enable',
        'title' => esc_html__('Scroll Top Button','liondar'),
        'type' => 'switcher',
        'desc' => esc_html__('Enable or Disable scroll button', 'liondar') ,
        'default' => true,
      ),

      array(
        'type' => 'subheading',
        'content' =>'<h3>'.esc_html__('Dark Mode Options','liondar').'</h3>'
      ),


    array(
        'id' => 'darkmode_enable',
        'title' => esc_html__('Enable Darkmode Button', 'liondar') ,
        'type' => 'switcher',
        'desc' => esc_html__('Enable or Disable Darkmode', 'liondar') ,
        'default' => true,
    ) ,




        )

    ));

    /*-------------------------------------
     ** Header Settings
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('Header', 'liondar') ,
        'parent' => 'theme_settings',
        'priority' => 11,
        'fields' => array(

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Header Layout', 'liondar') . '</h3>'
            ) ,

            array(
                'id' => 'nav_menu',
                'type' => 'image_select',
                'title' => esc_html__('Select Header Layout', 'liondar') ,
                'options' => array(
                    'nav-style-one' => LIONDAR_IMG . '/admin/header-style/style1.png',
                    'nav-style-two' => LIONDAR_IMG . '/admin/header-style/style2.png',
                ) ,
                'default' => 'nav-style-one'
            ) ,

            array(
                    'id' => 'theme_header_sticky',
                    'title' => esc_html__('Sticky Header', 'liondar') ,
                    'type' => 'switcher',
                    'desc' => esc_html__('Enable Sticky Header', 'liondar') ,
                    'default' => false,
            ) ,

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Header 1 - Components', 'liondar') . '</h3>'
            ) ,


            array(
                'id' => 'search_bar_enable',
                'title' => esc_html__('Search Box','liondar'),
                'type' => 'switcher',
                'desc' => esc_html__('Enable or Disable Search Box', 'liondar') ,
                'default' => true,
            ),

            array(
                'id' => 'burger_nav_enable',
                'title' => esc_html__('Right Burger Menu','liondar'),
                'type' => 'switcher',
                'desc' => esc_html__('Enable or Disable Burger Menu', 'liondar') ,
                'default' => true,
            ),

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Header 2 - Components', 'liondar') . '</h3>'
            ) ,

            array(
                'id' => 'search_bar_enable2',
                'title' => esc_html__('Search Box','liondar'),
                'type' => 'switcher',
                'desc' => esc_html__('Enable or Disable Search Box', 'liondar') ,
                'default' => true,
            ),

            array(
                'id' => 'burger_nav_enable2',
                'title' => esc_html__('Left Burger Menu','liondar'),
                'type' => 'switcher',
                'desc' => esc_html__('Enable or Disable Burger Menu', 'liondar') ,
                'default' => true,
            ),

            array(
                'id' => 'header_btn_right',
                'title' => esc_html__('Header Button', 'liondar') ,
                'type' => 'switcher',
                'desc' => esc_html__('Enable Header Right Button', 'liondar') ,
                'default' => true,
            ) ,

            array(
                'id' => 'header_btn_text',
                'type' => 'text',
                'title' => 'Right Button Text',
                'default' => esc_html__('SUBSCRIBE', 'liondar') ,
                'dependency' => array(
                    'header_btn_right',
                    '==',
                    'true'
                ) ,
            ) ,

            array(
                'id' => 'header_btn_link',
                'type' => 'text',
                'title' => 'Right Button Text',
                'default' => '#',
                'dependency' => array(
                    'header_btn_right',
                    '==',
                    'true'
                ) ,
            ) ,


            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Social Network', 'liondar') . '</h3>'
            ) ,

            array(
                'id' => 'header_social_enable',
                'title' => esc_html__('Show Header Social Icons', 'liondar') ,
                'type' => 'switcher',
                'desc' => esc_html__('Enable Header Social Icons', 'liondar') ,
                'default' => true,
            ) ,

            array(
                'id' => 'header-social-icon',
                'type' => 'repeater',
                'title' => 'Add New Social',
                'fields' => array(

                    array(
                        'id' => 'icon',
                        'type' => 'icon',
                        'title' => esc_html__('Pick Up Your Social Icon', 'liondar') ,
                    ) ,

                    array(
                        'id' => 'link',
                        'type' => 'text',
                        'title' => esc_html__('Inter Social Url', 'liondar') ,
                    ) ,

                ) ,
            ) ,

        )

    ));

    /*-------------------------------------
     ** Color Settings
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('Colors', 'liondar') ,
        'parent' => 'theme_settings',
        'priority' => 12,
        'fields' => array(

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Choose Theme Color', 'liondar') . '</h3>',
            ) ,

            array(
                'id' => 'theme_main_color',
                'type' => 'color',
                'title' => esc_html__('Primary Color', 'liondar') ,
                'default' => '#000000',
            ) ,


            array(
                'id' => 'theme_body_bg',
                'type' => 'color',
                'title' => esc_html__('Body Background Color', 'liondar') ,
                'default' => '#fff',
                'output'      => 'body',
                'output_mode' => 'background-color'
            ) ,

            array(
                'id' => 'theme_body_text',
                'type' => 'color',
                'title' => esc_html__('Body Text Color', 'liondar') ,
                'default' => '#000000',
                'output'      => 'body',
                'output_mode' => 'color'
            ) ,



        )

    ));




    /*-------------------------------------
     ** Typography Options
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('Typography', 'liondar') ,
        'parent' => 'theme_settings',
        'priority' => 14,
        'fields' => array(

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Body', 'liondar') . '</h3>'
            ) ,

            array(
                'id' => 'body-typography',
                'type' => 'typography',
                'output' => 'body',
                'default' => array(
                    'font-family' => 'Manrope',
                    'font-weight' => '400',
                    'font-size' => '18',
                    'line-height' => '26',
                    'letter-spacing' => '0',
                    'subset' => 'latin-ext',
                    'type' => 'google',
                    'unit' => 'px',
                ) ,

            ) ,

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Heading', 'liondar') . '</h3>'
            ) ,

            array(
                'id' => 'heading-one-typo',
                'type' => 'typography',

                'output' => array( 'h1', 'h2', 'h3', 'h4', 'h5', 'h6' ),
                'default' => array(
                    'color' => '#000',
                    'font-family' => 'Manrope',
                    'font-weight' => '600',
                    'subset' => 'latin-ext',
                    'text-align' => 'inherit',
                    'font-size' => false,
                    'type' => 'google',
                    'unit' => 'px',
                    'letter-spacing' => false,
                ) ,
                'extra-styles' => array(
                    '300',
                    '400',
                    '500',
                    '600',
                    '800',
                    '900'
                ) ,
            ) ,


            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Navigation', 'liondar') . '</h3>'
            ) ,

            array(
                'id' => 'nav-typography',
                'type' => 'typography',
                //'output' => array( 'h1', 'h2', 'h3', 'h4', 'h5', 'h6' ),
                'default' => array(
                    'color' => '#000',
                    'font-family' => 'Montserrat',
                    'font-weight' => '700',
                    'subset' => 'latin-ext',
                    'text-align' => 'left',
                    'type' => 'google',
                    'unit' => 'px',
                    'letter-spacing' => false,
                ) ,
                'extra-styles' => array(
                    '300',
                    '400',
                    '500',
                    '600',
                    '800',
                    '900'
                ) ,
            ) ,

        )
    ));

    /*-------------------------------------
     **Blog Settings
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('Blog: Listing', 'liondar') ,
        'parent' => 'theme_settings',
        'priority' => 15,
        'fields' => array(

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Blog Options', 'liondar') . '</h3>'
            ) ,

            array(
                'id' => 'blog_title',
                'type' => 'text',
                'title' => 'Blog Page Title',
                'default' => 'Blog Page',
                'desc' => 'Type Blog Page Title',
            ) ,

            array(
                'id' => 'page-spacing-blog',
                'type' => 'spacing',
                'title' => 'Blog Page Spacing',
                'output' => '.main-container.blog-spacing',
                'output_mode' => 'padding', // or margin, relative
                'default' => array(
                    'top' => '80',
                    'right' => '0',
                    'bottom' => '80',
                    'left' => '0',
                    'unit' => 'px',
                ) ,
            ) ,

            array(
                'id' => 'blog_breadcrumb_enable',
                'title' => esc_html__('Breadcrumb', 'liondar') ,
                'type' => 'switcher',
                'desc' => esc_html__('Enable Breadcrumb', 'liondar') ,
                'default' => true,
            ) ,

            array(
                'id' => 'show_blog_thumb',
                'title' => esc_html__('Show Post Image', 'liondar') ,
                'type' => 'switcher',
                'desc' => esc_html__('Show Blog Image', 'liondar') ,
                'default' => true,
            ) ,

            array(
                'id' => 'show_blog_cat',
                'title' => esc_html__('Show Catgeories', 'liondar') ,
                'type' => 'switcher',
                'desc' => esc_html__('Show Blog category', 'liondar') ,
                'default' => true,
            ) ,

            array(
                'id' => 'show_blog_date',
                'title' => esc_html__('Show Date', 'liondar') ,
                'type' => 'switcher',
                'desc' => esc_html__('Show Blog date', 'liondar') ,
                'default' => true,
            ) ,

            array(
                'id' => 'show_blog_excerpt',
                'title' => esc_html__('Show Excerpt', 'liondar') ,
                'type' => 'switcher',
                'desc' => esc_html__('Show Post Excerpt', 'liondar') ,
                'default' => true,
            ) ,

            array(
                'id' => 'set_blog_excerpt_limit',
                'type' => 'text',
                'title' => 'Post Excerpt Length',
                'default' => 32,
                'desc' => 'Set Blog Page Excerpt Length',
            ) ,

        )
    ));

    /*-------------------------------------
     **Category Settings
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('Category: Listing', 'liondar') ,
        'parent' => 'theme_settings',
        'priority' => 16,
        'fields' => array(


        array(
            'id' => 'cat_breadcrumb_enable',
            'title' => esc_html__('Breadcrumb', 'liondar') ,
            'type' => 'switcher',
            'desc' => esc_html__('Enable Breadcrumb', 'liondar') ,
            'default' => true,
        ) ,

        array(
        'id' => 'page-spacing-category',
        'type' => 'spacing',
        'title' => esc_html__('Category Page Spacing','liondar'),
        'output' => '.main-container.cat-page-spacing',
        'output_mode' => 'padding', // or margin, relative
        'default' => array(
            'top' => '75',
            'right' => '0',
            'bottom' => '75',
            'left' => '0',
            'unit' => 'px',
        ) ,
        ) ,

        array(
            'id' => 'cat_page_categroy',
            'title' => esc_html__('Show Catgeories', 'liondar') ,
            'type' => 'switcher',
            'desc' => esc_html__('Show Blog category', 'liondar') ,
            'default' => true,
        ) ,


        )
    ));

    /*-------------------------------------
     **Single Blog Settings
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('Blog: Single Post', 'liondar') ,
        'parent' => 'theme_settings',
        'priority' => 17,
        'fields' => array(

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Theme Blog Post Options. You can Customize Each Post by Editing Individually.', 'liondar') . '</h3>'
            ) ,

      
       array(
            'id' => 'liondar_single_blog_layout',
            'type' => 'image_select',
            'title' => esc_html__('Select Single Blog Style','liondar'),
            'options' => array(
                'single-one' => LIONDAR_IMG . '/admin/page/blog-1.png',
                'single-two' => LIONDAR_IMG . '/admin/page/blog-2.png',
            ),
            'default' => 'single-one'
        ),
        
        array(
            'id' => 'post-spacing-single',
            'type' => 'spacing',
            'title' => esc_html__('Single Blog Spacing','liondar'),
            'output' => '.single-one-bwrap',
            'output_mode' => 'padding', // or margin, relative
            'default' => array(
                'top' => '85',
                'right' => '0',
                'bottom' => '40',
                'left' => '0',
                'unit' => 'px',
            ) ,
        ) ,
        
        array(
            'id' => 'show_blog_details_thumb',
            'title' => esc_html__('Post Featured Image', 'liondar') ,
            'type' => 'switcher',
            'desc' => esc_html__('Show Blog Featured Image', 'liondar') ,
            'default' => true,
        ) ,
    
        array(
            'id' => 'blog_single_cat',
            'title' => esc_html__('Post Catgeory','liondar'),
            'type' => 'switcher',
            'desc' => esc_html__('Show Category Meta','liondar'),
            'default' => true,
        ),
        
        array(
            'id' => 'blog_single_author',
            'title' => esc_html__('Post Author','liondar'),
            'type' => 'switcher',
            'desc' => esc_html__('Show Author Meta','liondar'),
            'default' => true,
        ),

        array(
            'id' => 'blog_single_date',
            'title' => esc_html__('Post Date', 'liondar') ,
            'type' => 'switcher',
            'desc' => esc_html__('Show Date Meta', 'liondar') ,
            'default' => true,
        ) ,

        array(
            'id' => 'blog_social',
            'title' => esc_html__('Social Share Box','liondar'),
            'type' => 'switcher',
            'desc' => esc_html__('Show Social Share Box','liondar'),
            'default' => false,
        ),

        array(
            'id' => 'blog_tags',
            'title' => esc_html__('Show Tags','liondar'),
            'type' => 'switcher',
            'desc' => esc_html__('Show Post Tags','liondar'),
            'default' => false,
        ),

        array(
            'id' => 'blog_author_box',
            'title' => esc_html__('Author Box','liondar'),
            'type' => 'switcher',
            'desc' => esc_html__('Show Post Author Box','liondar'),
            'default' => false,
        ),


        array(
            'id' => 'blog_nav',
            'title' => esc_html__('Show Navigation','liondar'),
            'type' => 'switcher',
            'desc' => esc_html__('Post Navigation','liondar'),
            'default' => true,
        ),

        array(
            'id'         => 'blog_prev_title',
            'type'       => 'text',
            'title'      => esc_html__('Previous Post Text','liondar'),
            'default'    => esc_html__('Previous Post','liondar'),
            'desc'       => esc_html__('Type Previous Post Link Title','liondar'),
        ),
        
        array(
            'id'         => 'blog_next_title',
            'type'       => 'text',
            'title'      => esc_html__('Next Post Text','liondar'),
            'default'    => esc_html__('Next Post','liondar'),
            'desc'       => esc_html__('Type Next Post Link Title','liondar'),
        ),
        
        
        array(
            'id' => 'blog_related',
            'title' => esc_html__('Show Related Posts','liondar'),
            'type' => 'switcher',
            'desc' => esc_html__('Related Posts','liondar'),
            'default' => false,
        ),    


        )
    ));

    /*-------------------------------------
     ** Error Page Options
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('Error Page', 'liondar') ,
        'parent' => 'theme_settings',
        'priority' => 18,
        'fields' => array(

            array( //nav bar one start
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('404 Options', 'liondar') . '</h3>'
            ) ,

            array(
                'id' => 'error_title',
                'type' => 'text',
                'title' => 'Error Page Title',
                'default' => 'OOPS THAT PAGE CANT BE FOUND',
            ) ,

            array(
                'id' => 'error_btn_text',
                'type' => 'text',
                'title' => 'Error Page Button Text',
                'default' => 'Go To Homepage',
            ) ,

            array(
                'id' => 'page-spacing-error',
                'type' => 'spacing',
                'title' => 'Page Spacing',
                'output' => 'body.error404 .main-container',
                'output_mode' => 'padding', // or margin, relative
                'default' => array(
                    'top' => '75',
                    'right' => '0',
                    'bottom' => '75',
                    'left' => '0',
                    'unit' => 'px',
                ) ,
            ) ,

        )
    ));


/*-------------------------------------------------------
   ** Woocommerce  Options
--------------------------------------------------------*/
    
  CSF::createSection($prefix . '_customize_options', array(
    'title'  => esc_html__('Shop','liondar'),
    'id' => 'cat_page',
    'icon' => 'fa fa-pencil-square-o',
    'fields' => array(
      array(
        'type' => 'subheading',
        'content' => '<h3>' . esc_html__('Shop Layout', 'liondar') . '</h3>'
      ),
      
      
        array(
            'id' => 'shop_layout',
            'type' => 'image_select',
            'title' => esc_html__('Shop Layout','liondar'),
            'options' => array(
             
                'right-sidebar' => LIONDAR_IMG . '/admin/header-style/R.png',
                'left-sidebar' => LIONDAR_IMG . '/admin/header-style/L.png',
                'no-sidebar' => LIONDAR_IMG . '/admin/header-style/D.png',
            ),
            
            'default' => 'right-sidebar'
        ),


        )
    ));
	
	
    /*-------------------------------------
     ** Footer Options
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('Footer Settings', 'liondar') ,
        'parent' => 'theme_settings',
        'priority' => 21,
        'fields' => array(

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Footer Layout', 'liondar') . '</h3>'
            ) ,

            array(
                'id' => 'footer_style',
                'type' => 'image_select',
                'title' => esc_html__('Select Footer Layout', 'liondar') ,
                'options' => array(
                    'footer-style-one' => LIONDAR_IMG . '/admin/header-style/footer-1.png',
                    'footer-style-two' => LIONDAR_IMG . '/admin/header-style/footer-2.png',
                ) ,
                'default' => 'footer-style-one'
            ) ,

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Footer Layout 2 Options', 'liondar') . '</h3>'
            ) ,
            

            array(
                'id' => 'footer_nav_two',
                'title' => esc_html__('Footer 2 Navigation.', 'liondar') ,
                'type' => 'switcher',
                'default' => false,
            ) ,

            array(
                'id' => 'footer_bold_slogan_img',
                'title' => esc_html__('Footer Slogan Image', 'liondar'),
                'type'    => 'media',
                'title'   => 'Footer Slogan Image',
                'library' => 'image',
            ),

            array(
                'id' => 'copyright_text',
                'title' => esc_html__('Display Copyright Area for Footer 2', 'liondar') ,
                'type' => 'textarea',
            ) ,

            array(
                'id' => 'footer_social_enable',
                'title' => esc_html__('Do You want to Show Footer Social Icons', 'liondar') ,
                'type' => 'switcher',
                'default' => false,
            ) ,

            array(
                'id' => 'social-icon',
                'type' => 'repeater',
                'title' => 'Repeater',
                'dependency' => array(
                    'footer_social_enable',
                    '==',
                    'true'
                ) ,
                'fields' => array(
                    array(
                        'id' => 'icon',
                        'type' => 'icon',
                        'title' => esc_html__('Pick Up Your Social Icon', 'liondar') ,
                    ) ,
                    array(
                        'id' => 'link',
                        'type' => 'text',
                        'title' => esc_html__('Inter Social Url', 'liondar') ,
                    ) ,
                ) ,
            ) ,
        )
    ));




}

