<?php

/**
 * Elementor Widget
 * @package Liondar
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class liondar_post_tab_grid extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'posts-tab-grid';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Liondar Posts Tab Grid', 'liondar-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-picture-o';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'liondar_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {
		$this->tab_options();		
		$this->post_query_options();	
		$this->meta_options();	
		$this->design_options();
	}
	
	/**
    * Tab Item Options
    */
    private function tab_options() {
	
	
		$this->start_controls_section(
            'tab_option',
            [
                'label' => __( 'Tab Item and Content', 'liondar-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		
		$this->add_control(
			'tabsec_top_title',
			[
				'label' => __( 'Section Title', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' => __( 'Latest Articles', 'plugin-domain' ),
				'placeholder' => __( 'Discover articles in all topics', 'plugin-domain' ),
			]
		);

		
		$this->add_control(
         'tabs',
         [
             'label' => esc_html__('Tab Items', 'liondar-extra'),
             'type' => \Elementor\Controls_Manager::REPEATER,
             'default' => [
                 [
                     'tab_title' => esc_html__('Add Tab Item Menu', 'liondar-extra'),
                 ],
             ],
			 
             'fields' => [

             	[   'name' => 'tab_menu_name',
                     'label'         => esc_html__( 'Tab Menu Name', 'liondar-extra' ),
                     'type'          => \Elementor\Controls_Manager::TEXT,
                     'default'       => 'Add Tab Menu',
                ],

			 
                [   'name' => 'post_categories',
                     'label' =>esc_html__('Select Categories', 'liondar-extra'),
                     'type'      => \Elementor\Controls_Manager::SELECT2,
                     'options'   => $this->posts_cat_list(),
                     'label_block' => true,
                     'multiple'  => true,
					 'placeholder' => __( 'All Categories', 'liondar-extra' ),
                ],

                [   'name' => 'post_tags',
                     'label' =>esc_html__('Select Tags', 'liondar-extra'),
                     'type'      => \Elementor\Controls_Manager::SELECT2,
                     'options'   => $this->liondar_get_post_tags(),
                     'label_block' => true,
                     'multiple'  => true,
					 'placeholder' => __( 'All Tags', 'liondar-extra' ),
                ],


                [   
                  'name' => 'enable_offset_post',
                  'label'         => esc_html__( 'Enable Skip Post', 'liondar-extra' ),
                  'type' => \Elementor\Controls_Manager::SWITCHER,
                  'label_on' => esc_html__('Yes', 'liondar-extra'),
                  'label_off' => esc_html__('No', 'liondar-extra'),
				  'default' => 'no',
                ],
			   
                [  
                   'name' => 'post_offset_count',
                   'label'         => esc_html__( 'Skip Post Count', 'liondar-extra' ),
                   'type'          => \Elementor\Controls_Manager::NUMBER,
                   'default'       => '1',
                   'condition' => [ 'enable_offset_post' => 'yes' ]
                ],
			   
             ],
         ]
     );
				
		
		$this->end_controls_section();
	
	}
	
	/**
    * Post Query Options
    */
    private function post_query_options() {
	
	
		$this->start_controls_section(
            'post_query_option',
            [
                'label' => __( 'Post Options', 'liondar-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		
		// Post Items
		
        $this->add_control(
            'post_number',
			[
				'label'         => esc_html__( 'Number Of Posts', 'liondar-extra' ),
				'type'          => \Elementor\Controls_Manager::NUMBER,
				'default'       => '1',
			]
        );
		
		
		// Post Sort
		
        $this->add_control(
            'post_sorting',
            [
                'type'    => \Elementor\Controls_Manager::SELECT2,
                'label' => esc_html__('Post Sorting', 'liondar-extra'),
                'default' => 'date',
                'options' => [
					'date' => esc_html__('Recent Post', 'liondar-extra'),
                    'rand' => esc_html__('Random Post', 'liondar-extra'),
					'title'         => __( 'Title Sorting Post', 'liondar-extra' ),
                    'modified' => esc_html__('Last Modified Post', 'liondar-extra'),
                    'comment_count' => esc_html__('Most Commented Post', 'liondar-extra'),
					
                ],
            ]
        );		
		
		// Post Order
		
        $this->add_control(
            'post_ordering',
            [
                'type'    => \Elementor\Controls_Manager::SELECT2,
                'label' => esc_html__('Post Ordering', 'liondar-extra'),
                'default' => 'DESC',
                'options' => [
					'DESC' => esc_html__('Desecending', 'liondar-extra'),
                    'ASC' => esc_html__('Ascending', 'liondar-extra'),
                ],
            ]
        );

		
		$this->end_controls_section();
	
	}	
	
	/**
    * Meta Options
    */
    private function meta_options() {
	
	
		$this->start_controls_section(
            'meta_option',
            [
                'label' => __( 'Meta Options', 'liondar-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		
		$this->add_control(
            'display_cat',
            [
                'label' => esc_html__('Display Category Name', 'liondar-extra'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'liondar-extra'),
                'label_off' => esc_html__('No', 'liondar-extra'),
                'default' => 'yes',
            ]
        );
		
		
		$this->add_control(
            'display_excerpt',
            [
                'label' => esc_html__('Display Post Excerpt', 'ennlil-extra'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'ennlil-extra'),
                'label_off' => esc_html__('No', 'ennlil-extra'),
                'default' => 'yes',
            ]
        );
		
		$this->add_control(
            'display_tab_grid_meta',
            [
                'label' => esc_html__('Display Tab Post Meta', 'ennlil-extra'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'ennlil-extra'),
                'label_off' => esc_html__('No', 'ennlil-extra'),
                'default' => 'yes',
            ]
        );
		


	
		$this->end_controls_section();
	
	}	
	
	/**
    * Design Options
    */
    private function design_options() {
	
	
		$this->start_controls_section(
            'design_option',
            [
                'label' => __( 'Design Options', 'liondar-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		

		
			$this->add_responsive_control(
			'tab_grid_post_img_height',
			[
				'label' =>esc_html__( 'Set Large Post Image height', 'liondar-extra' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'desktop_default' => [
					'size' => 435,
					'unit' => 'px',
				],
				'tablet_default' => [
					'size' => 435,
					'unit' => 'px',
				],
				'mobile_default' => [
					'size' =>435,
					'unit' => 'px',
				],
				
				'default'  => [
					'unit' => 'px',
					'size' => 435,
				],
				
				'selectors' => [
					'{{WRAPPER}} .theme-tab-grid-wrapper .post-block-col-one.tab-grid-post-item .news-post-grid-thumbnail a img' => 'height: {{SIZE}}{{UNIT}}!important;',
				],
			]
		);	
	

		
		$this->add_control(
          'title_length',
          [
            'label'         => esc_html__( 'Big Block Post Title Length', 'liondar-extra' ),
            'type'          => \Elementor\Controls_Manager::NUMBER,
            'default'       => '10',
          ]
        );
		
		$this->add_control(
          'content_length',
          [
            'label'         => esc_html__( 'Post Excerpt Length', 'ennlil-extra' ),
            'type'          => \Elementor\Controls_Manager::NUMBER,
            'default'       => '15',
          ]
        );
		
		
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'tab_grid_sec_title_typography',
				'label' => __( 'Section Title Typography', 'liondar-extra' ),
				'selector' => '{{WRAPPER}} .theme-tab-grid-wrapper .tab-section-title h2',
			]
		);

        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'tab_grid_title_typo',
				'label' => __( 'Post Title Typography', 'liondar-extra' ),
				'selector' => '{{WRAPPER}} .theme-tab-grid-wrapper .tab-grid-post-item h3.post-title',
			]
		);


		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'tab_grid_content_typo',
				'label' => __( 'Small Paragraph Typography', 'liondar-extra' ),
				'selector' => '{{WRAPPER}} .theme-tab-grid-wrapper .tab-grid-post-item .post-excerpt-box p',
			]
		);
		
		
		$this->add_group_control(
           \Elementor\Group_Control_Typography::get_type(),
           [
              'name' => 'tab_grid_cat_meta_typo',
              'label' => esc_html__( 'Category Meta Typography', 'liondar-extra' ),
              'selector' => '{{WRAPPER}} .theme-tab-grid-wrapper .tab-grid-post-item .post-category-box a.news-cat_Name',
           ]
        );
		
		 
		$this->add_group_control(
           \Elementor\Group_Control_Typography::get_type(),
           [
              'name' => 'tab_grid_meta_typo',
              'label' => esc_html__( 'Post Meta Typography', 'liondar-extra' ),
              'selector' => '{{WRAPPER}} .theme-tab-grid-wrapper .tab-grid-post-item .post-block-meta-list',
           ]
        );


		$this->end_controls_section();
	
	}	
		


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

		
		$title_limit = $settings['title_length'];
		$content_limit = $settings['content_length'];
		
		$post_number        = $settings['post_number'];
		$post_order         = $settings['post_ordering'];
        $post_sortby        = $settings['post_sorting'];

        $display_blog_excerpt = $settings['display_excerpt']; 
		
		$display_blog_cat = $settings['display_cat'];
		
		$display_tab_top_meta = $settings['display_tab_grid_meta'];


		
		$tabs               = $settings['tabs'];
        $post_count         = count($tabs);

	?>



	    <div class="theme-post-tab-wrapper blog-tab-wrapper theme-tab-grid-wrapper">
            <div class="post-tab-block-element news_tab_Block">
				
				<div class="tab-section-title">
					<h2><?php echo wp_kses_post( $settings['tabsec_top_title']  ); ?></h2>
				</div>
				
				<ul class="nav nav-tabs" id="myTab" role="tablist">

					<span class="tab-filter-title">FILTER BY CATEGORY</span>

                        <?php
                              foreach ( $tabs as $tab_Menu_key=>$value ) {
                                       
                                    if( $tab_Menu_key == 0 ){

                                echo '<li class="nav-item" role="presentation"><button class="nav-link active" data-bs-toggle="tab" data-bs-target="#a'.$this->get_id().$value['_id'].'" type="button" role="tab" aria-controls="home" aria-selected="true">'.$value['tab_menu_name'].'</button></li>';


                                    } else {

                                echo '<li class="nav-item" role="presentation"><button class="nav-link" data-bs-toggle="tab" data-bs-target="#a'.$this->get_id().$value['_id'].'" type="button" role="tab" aria-controls="profile" aria-selected="false">'.$value['tab_menu_name'].'</button></li>';         


                                    }
                                 
                              }
                        ?>
                </ul>


                    <div class="theme_post_Tab__content theme_post_Tabone__content tab-content" id="myTabContent">

                     <?php
                     
                     foreach ($tabs as $tab_Content_key=>$value) {
                      
                        if( $tab_Content_key == 0){
                           echo '<div role="tabpanel" class="tab-pane fade show active" id="a'.$this->get_id().$value['_id'].'" role="tabpanel" aria-labelledby="home-tab">';
                        } else {
                           echo '<div role="tabpanel" class="tab-pane fade" id="a'.$this->get_id().$value['_id'].'" role="tabpanel" aria-labelledby="home-tab">';
                        }
                        
                        $args = array(
                           'post_type'   =>  'post',
                           'post_status' => 'publish',
                           'posts_per_page' => $post_number,
                           'order' => $post_order,
                           'orderby' => $post_sortby,
                           'tag__in' => $value['post_tags'],
                           'ignore_sticky_posts' => 1,
                        );
						
						
						// Category
						
						if ( ! empty( $value['post_categories'] ) ) {
							$args['category_name'] = implode(',', $value['post_categories']);
						}
		
						// Post Offset
						
						if($value['enable_offset_post'] == 'yes') {
							$args['offset'] = $value['post_offset_count'];
						}
                   
                   
                       $Tabquery = new \WP_Query( $args );
                     
                     ?>


                    <?php if ( $Tabquery->have_posts() ) : ?>
					 
                        <div class="theme_post_Tab__block block-tab-item">
                            <div class="row">
							  
								<?php while ($Tabquery->have_posts()) : $Tabquery->the_post();?>
							
								
								<div class="col-xl-4 col-lg-12">
								
									<div class="tab-grid-post-item">
										
										<div class="post-grid-thumbnail">
											<a href="<?php the_permalink(); ?>" class="news-post-grid-thumbnail-wrap">
												<img src="<?php echo esc_attr(esc_url(get_the_post_thumbnail_url(null, 'full'))); ?>" alt="<?php the_title_attribute(); ?>">
											</a>
										</div>
										
										<div class="post-grid-content">
											
											<?php if($display_blog_cat=='yes'): ?>	
											<div class="post-category-box post-block-meta-cat">
											<?php require LIONDAR_THEME_DIR . '/template-parts/cat-alt-template.php'; ?>
											</div>
											<?php endif; ?>	
											
											<h3 class="post-title">
												<a href="<?php the_permalink(); ?>"><?php echo esc_html( wp_trim_words(get_the_title(), $title_limit,'') ); ?></a>
											</h3>
										
											<?php if($display_blog_excerpt =='yes'): ?> 
											<div class="post-excerpt-box">
												<p><?php echo esc_html( wp_trim_words(get_the_excerpt(), $content_limit ,'') );?></p>
											</div>
											<?php endif; ?>	
											
											<?php if($display_tab_top_meta=='yes'): ?>
											
											<div class="post-block-meta-list">
												
												<div class="post-meta-author-box">
													BY <?php echo get_the_author_link(); ?>
												</div>

												<div class="post-meta-date-box">
													<?php echo esc_html( get_the_date( 'F j, Y' ) ); ?>
												</div>
												
											</div>
											
											
											<?php endif; ?>	
											
											
										</div>
										
									</div>

								</div>
								
                                	
								<?php endwhile; ?>
								
                            </div>

                            <div class="row">
                            	<div class="col-lg-12">
                            		<div class="tab-item-bottom-button">
										<a href="#">VIEW ALL</a>
									</div>
                            	</div>
                            </div>


						</div>
                        <?php wp_reset_postdata(); ?>
                     <?php endif; ?>
					 
                     </div>
                     <?php } ?>
                </div>
          </div>
      </div>


	<?php 
	
    }
		
   
   	public function posts_cat_list() {
		
		$terms = get_terms( array(
            'taxonomy'    => 'category',
            'hide_empty'  => true
		) );

      $cat_list = [];
      foreach($terms as $post) {
      	$cat_list[$post->slug]  = [$post->name];
      }
      return $cat_list;
	
	}	

	public function liondar_get_post_tags() {
		$terms = get_terms( array(
			'taxonomy'    => 'post_tag',
			'hide_empty'  => false,
			'posts_per_page' => -1, 
		) );
		$cat_list = [];
		foreach($terms as $post) {
		$cat_list[$post->term_id]  = [$post->name];
		}
		return $cat_list;
	}
	

}

