<?php

/**
 * Elementor Widget
 * @package Liondar
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class liondar_post_trending_list extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'posts-trendning-list';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Trending Post List', 'liondar-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'liondar_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {
		$this->layout_options();		
		$this->post_query_options();	
		$this->meta_options();	
		$this->design_options();
	}
	
	/**
    * Layout Options
    */
    private function layout_options() {
	
	
		$this->start_controls_section(
            'layout_option',
            [
                'label' => __( 'Layout Options', 'liondar-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
				
		
		$this->add_control(
            'display_trending_title',
            [
                'label' => esc_html__('Display Section Title', 'finmag-extra'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'finmag-extra'),
                'label_off' => esc_html__('No', 'finmag-extra'),
                'default' => 'yes',
            ]
        );

        $this->add_control(
			'post_trending_title',
			[
				'label' => __( 'Section Title', 'finmag-extra' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' => __( 'TRENDING', 'finmag-extra' ),
				'placeholder' => __( 'Type Your title here', 'finmag-extra' ),
			]
		);


		$this->add_control(
            'display_post_thumbnail',
            [
                'label' => esc_html__('Display Post Thumbnail', 'finmag-extra'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'finmag-extra'),
                'label_off' => esc_html__('No', 'finmag-extra'),
                'default' => 'no',
            ]
        );

		$this->add_responsive_control(
			'post_trending_list_img_width',
			[
				'label' =>esc_html__( 'Set Post Image Width', 'liondar-extra' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'desktop_default' => [
					'size' => 180,
					'unit' => 'px',
				],
				'tablet_default' => [
					'size' => 180,
					'unit' => 'px',
				],
				'mobile_default' => [
					'size' =>180,
					'unit' => 'px',
				],
				
				'default'  => [
					'unit' => 'px',
					'size' => 180,
				],
				
				'selectors' => [
					'{{WRAPPER}} .trending-post-list-wrapper .post-block-media-wrap' => 'min-width: {{SIZE}}{{UNIT}}!important;',
				],
			]
		);				
		
		
		$this->add_responsive_control(
			'post_trending_list_img_height',
			[
				'label' =>esc_html__( 'Set Post Image height', 'liondar-extra' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'desktop_default' => [
					'size' => 130,
					'unit' => 'px',
				],
				'tablet_default' => [
					'size' => 130,
					'unit' => 'px',
				],
				'mobile_default' => [
					'size' =>130,
					'unit' => 'px',
				],
				
				'default'  => [
					'unit' => 'px',
					'size' => 130,
				],
				
				'selectors' => [
					'{{WRAPPER}} .trending-post-list-wrapper .post-block-media-wrap a img' => 'height: {{SIZE}}{{UNIT}}!important;',
				],
			]
		);	



		$this->end_controls_section();
	
	}
	
	/**
    * Post Query Options
    */
    private function post_query_options() {
	
	
		$this->start_controls_section(
            'post_query_option',
            [
                'label' => __( 'Post Options', 'liondar-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		
		
		// Post Sort
		
        $this->add_control(
            'post_sorting',
            [
                'type'    => \Elementor\Controls_Manager::SELECT2,
                'label' => esc_html__('Post Sorting', 'liondar-extra'),
                'default' => 'date',
                'options' => [
					'date' => esc_html__('Recent Post', 'liondar-extra'),
                    'rand' => esc_html__('Random Post', 'liondar-extra'),
					'title'         => __( 'Title Sorting Post', 'liondar-extra' ),
                    'modified' => esc_html__('Last Modified Post', 'liondar-extra'),
                    'comment_count' => esc_html__('Most Commented Post', 'liondar-extra'),
					
                ],
            ]
        );		
		
		// Post Order
		
        $this->add_control(
            'post_ordering',
            [
                'type'    => \Elementor\Controls_Manager::SELECT2,
                'label' => esc_html__('Post Ordering', 'liondar-extra'),
                'default' => 'DESC',
                'options' => [
					'DESC' => esc_html__('Desecending', 'liondar-extra'),
                    'ASC' => esc_html__('Ascending', 'liondar-extra'),
                ],
            ]
        );
		
		
		// Post Categories
		
		$this->add_control(
            'post_categories',
            [
                'type'      => \Elementor\Controls_Manager::SELECT2,
				'label' =>esc_html__('Select Categories', 'liondar-extra'),
                'options'   => $this->posts_cat_list(),
                'label_block' => true,
                'multiple'  => true,
            ]
        );
	
		
		
		// Post Items.
		
        $this->add_control(
            'post_number',
			[
				'label'         => esc_html__( 'Number Of Posts', 'liondar-extra' ),
				'type'          => \Elementor\Controls_Manager::NUMBER,
				'default'       => '2',
			]
        );
		
		$this->add_control(
            'enable_offset_post',
            [
               'label' => esc_html__('Enable Skip Post', 'liondar-extra'),
               'type' => \Elementor\Controls_Manager::SWITCHER,
               'label_on' => esc_html__('Yes', 'liondar-extra'),
               'label_off' => esc_html__('No', 'liondar-extra'),
               'default' => 'no',
               
            ]
        );
      
        $this->add_control(
			'post_offset_count',
			  [
			   'label'         => esc_html__( 'Skip Post Count', 'liondar-extra' ),
			   'type'          => \Elementor\Controls_Manager::NUMBER,
			   'default'       => '1',
			   'condition' => [ 'enable_offset_post' => 'yes' ]

			  ]
        );
		
		// Specific Posts by ID.
        $this->add_control(
            'post_ids',
            [
                'type'        => \Elementor\Controls_Manager::TEXT,
                'label'       => __( 'Show specific posts by ID', 'liondar-extra' ),
                'placeholder' => __( 'ex.: 256, 54, 78', 'liondar-extra' ),
                'description'   => __( 'Paste post ID\'s separated by commas. To find ID, click edit post and you\'ll find it in the browser address bar', 'liondar-extra' ),
                'default'     => '',
                'separator'     => 'before',
                'label_block' => true,
            ]
        );

		
		$this->end_controls_section();
	
	}	
	
	/**
    * Meta Options
    */
    private function meta_options() {
	
	
		$this->start_controls_section(
            'meta_option',
            [
                'label' => __( 'Meta Options', 'liondar-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		
		$this->add_control(
            'display_excerpt',
            [
                'label' => esc_html__('Display Post Excerpt', 'ennlil-extra'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'ennlil-extra'),
                'label_off' => esc_html__('No', 'ennlil-extra'),
                'default' => 'no',
            ]
        );
		

     	$this->add_control(
            'display_cat',
            [
                'label' => esc_html__('Display Category Name', 'liondar-extra'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'liondar-extra'),
                'label_off' => esc_html__('No', 'liondar-extra'),
                'default' => 'yes',
            ]
        );
		
		$this->add_control(
            'display_date',
            [
                'label' => esc_html__('Display Post Date', 'liondar-extra'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'liondar-extra'),
                'label_off' => esc_html__('No', 'liondar-extra'),
                'default' => 'yes',
            ]
        );
		

		$this->add_control(
            'display_post_block_meta',
            [
                'label' => esc_html__('Display Post Meta', 'ennlil-extra'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'ennlil-extra'),
                'label_off' => esc_html__('No', 'ennlil-extra'),
                'default' => 'yes',
            ]
        );


 
		
	
		$this->end_controls_section();
	
	}	
	
	/**
    * Design Options
    */
    private function design_options() {
	
	
		$this->start_controls_section(
            'design_option',
            [
                'label' => __( 'Typography', 'liondar-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		
		$this->add_group_control(
           \Elementor\Group_Control_Typography::get_type(),
           [
              'name' => 'post_trending_section_title',
              'label' => esc_html__( 'Section Title Typography', 'liondar-extra' ),
              'selector' => '{{WRAPPER}} .trending-post-list-wrapper .post-block-title-wrapper h2.post-block-title',
           ]
        );

		$this->add_group_control(
           \Elementor\Group_Control_Typography::get_type(),
           [
              'name' => 'post_trending_list_title',
              'label' => esc_html__( 'Post Title Typography', 'liondar-extra' ),
              'selector' => '{{WRAPPER}} .trending-post-list-wrapper article.post-trending-list-item .post-trending-item-inner .post-item-title h2.post-title',
           ]
        );	


		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'post_trending_list_excerpt',
				'label' => __( 'Post Excerpt Typography', 'liondar-extra' ),
				'selector' => '{{WRAPPER}} .trending-post-list-wrapper article.post-trending-list-item .post-trending-item-inner .post-excerpt-box p',
			]
		);
		
		
		$this->add_group_control(
           \Elementor\Group_Control_Typography::get_type(),
           [
              'name' => 'post_trending_list_cat',
              'label' => esc_html__( 'Category Meta Typography', 'liondar-extra' ),
              'selector' => '{{WRAPPER}} article.post-trending-list-item .post-trending-item-inner .post-category-box a',
           ]
        );
		
		 
		$this->add_group_control(
           \Elementor\Group_Control_Typography::get_type(),
           [
              'name' => 'post_trending_list_date',
              'label' => esc_html__( 'Post Date Typography', 'liondar-extra' ),
              'selector' => '{{WRAPPER}} aarticle.post-trending-list-item .post-trending-item-inner .post-meta-date-box',
           ]
        );


		$this->add_control(
          'title_length',
          [
            'label'         => esc_html__( 'Post Title Length', 'liondar-extra' ),
            'type'          => \Elementor\Controls_Manager::NUMBER,
            'default'       => '20',
          ]
        );

        $this->add_control(
          'content_length',
          [
            'label'         => esc_html__( 'Post Excerpt Length', 'ennlil-extra' ),
            'type'          => \Elementor\Controls_Manager::NUMBER,
            'default'       => '20',
          ]
        );
		

		
		$this->end_controls_section();
	
	}	
		


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

		$string_ID = $settings['post_ids'];
        $post_ID = ( ! empty( $string_ID ) ) ? array_map( 'intval', explode( ',', $string_ID ) ) : '';

		$display_trending_title = $settings['display_trending_title'];

		$display_post_thumbnail = $settings['display_post_thumbnail'];

		$title_limit = $settings['title_length'];
		$content_limit = $settings['content_length'];
		$post_count = $settings['post_number'];
		$post_order  = $settings['post_ordering'];
		$post_sortby = $settings['post_sorting']; 
		
		$display_blog_excerpt = $settings['display_excerpt'];
		$display_blog_cat = $settings['display_cat'];
		$display_blog_date = $settings['display_date'];



		$display_post_block_meta = $settings['display_post_block_meta'];

		
		$args = [
            'post_type' => 'post',
            'post_status' => 'publish',
			'order' => $settings['post_ordering'],
			'posts_per_page' => $settings['post_number'],
			'ignore_sticky_posts' => 1,
        ];
		
		// Category
        if ( ! empty( $settings['post_categories'] ) ) {
            $args['category_name'] = implode(',', $settings['post_categories']);
        }
		
		// Post Sorting
        if ( ! empty( $settings['post_sorting'] ) ) {
            $args['orderby'] = $settings['post_sorting'];
        }	
		
		// Specific Posts by ID's
        if ( ! empty( $settings['post_ids'] ) ) {
            $args['post__in'] = $post_ID;
        }

		// Post Offset		
		if($settings['enable_offset_post'] == 'yes') {
			$args['offset'] = $settings['post_offset_count'];
		}

		// Query
        $query = new \WP_Query( $args ); ?>
		
		

		
		<?php if ( $query->have_posts() ) : ?>


		<div class="trending-post-list-wrapper <?php if($display_post_thumbnail == "yes" ) { echo "trendning-list-has-meida"; } else { echo "trendning-list-no-meida"; } ?>">
			
			<?php if($display_trending_title=='yes'): ?>
			<div class="post-block-title-wrapper">
                <h2 class="post-block-title"><?php echo wp_kses_post( $settings['post_trending_title']  ); ?></h2>
            </div>
        	<?php endif; ?>

			

			<?php while ($query->have_posts()) : $query->the_post(); ?>


			<article <?php post_class('post-trending-list-item'); ?>>

				<?php if($display_post_thumbnail == 'yes'): ?>
				<div class="post-block-media-wrap">
					<a href="<?php the_permalink(); ?>">
						<img src="<?php echo esc_attr(esc_url(get_the_post_thumbnail_url(null, 'full'))); ?>" alt="<?php the_title_attribute(); ?>">
					</a>
				</div>

				<?php endif; ?>


				<div class="post-trending-item-inner">

					<?php if($display_post_block_meta=='yes'): ?>
					<div class="post-block-meta-list">

						<?php if($display_blog_cat=='yes'): ?>	
						<div class="post-category-box">
						<?php require LIONDAR_THEME_DIR . '/template-parts/cat-alt-template.php'; ?>
						</div>
						<?php endif; ?>
						
						<?php if($display_blog_date=='yes'): ?>
						<div class="post-meta-date-box">
							<?php echo esc_html( get_the_date( 'F j, Y' ) ); ?>
						</div>
						<?php endif; ?>
						
					</div>
					<?php endif; ?>
								
					<div class="post-item-title">
						<h2 class="post-title">
						<a href="<?php the_permalink(); ?>"><?php echo esc_html( wp_trim_words(get_the_title(), $title_limit,'') ); ?></a>
						</h2>
					</div>


					<?php if($display_blog_excerpt =='yes'): ?> 
					<div class="post-excerpt-box">
						<p><?php echo esc_html( wp_trim_words(get_the_excerpt(), $content_limit ,'') );?></p>
					</div>
					<?php endif; ?>	
								
			

					</div>
				
				</article>		
							

			<?php endwhile; ?>
		
		<?php wp_reset_postdata(); ?>
		
		</div>

		<?php endif; ?>
		

	
	<?php 
}
		
   
   	public function posts_cat_list() {
		
		$terms = get_terms( array(
			'taxonomy'    => 'category',
			'hide_empty'  => true
		) );

		$cat_list = [];
		foreach($terms as $post) {
		$cat_list[$post->slug]  = [$post->name];
		}
		return $cat_list;
	  
	}		
	
}

